@@ -2,13 +2,13 @@
 
 #  Copyright 2022 Commonwealth Scientific and Industrial Research
 #  Organisation (CSIRO) ABN 41 687 119 230.
-# 
+#
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
 #  You may obtain a copy of the License at
-# 
+#
 #      http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 #  Unless required by applicable law or agreed to in writing, software
 #  distributed under the License is distributed on an "AS IS" BASIS,
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -25,13 +25,20 @@ HERE = os.path.abspath(os.path.dirname(__file__))
 pc = PathlingContext.create()
 
 csv = pc.spark.read.options(header=True).csv(
-        f'file://{os.path.join(HERE, "data/csv/conditions.csv")}')
-
-result = pc.member_of(csv, to_coding(csv.CODE, 'http://snomed.info/sct'),
-                      to_ecl_value_set("""
-<< 64572001|Disease| : (
-  << 370135005|Pathological process| = << 441862004|Infectious process|,
-  << 246075003|Causative agent| = << 49872002|Virus|
+    f'file://{os.path.join(HERE, "data/csv/conditions.csv")}'
 )
-                      """), 'VIRAL_INFECTION')
-result.select('CODE', 'DESCRIPTION', 'VIRAL_INFECTION').show()
+
+result = pc.member_of(
+    csv,
+    to_coding(csv.CODE, "http://snomed.info/sct"),
+    to_ecl_value_set(
+        """
+        << 64572001|Disease| : (
+          << 370135005|Pathological process| = << 441862004|Infectious process|,
+          << 246075003|Causative agent| = << 49872002|Virus|
+        )
+                              """
+    ),
+    "VIRAL_INFECTION",
+)
+result.select("CODE", "DESCRIPTION", "VIRAL_INFECTION").show()
